#ifndef NT2_INCLUDE_FUNCTIONS_ONEMINUS_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ONEMINUS_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/oneminus.hpp>

#endif
